@@ -1,5 +1,5 @@
 #Boa:Dialog:preferences
-#TunaPie (c)2005-2006 James Stone. Released under the GNU GPL.
+#TunaPie (c)2005-2008 James Stone. Released under the GNU GPL.
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -18,10 +18,8 @@
 #Written using Boa-Constructor.
 #http://boa-constructor.sourceforge.net/
 #
-#Version 0.4.8 15/11/06
+#Version 0.4.11 1/11/07
 
-import wxversion
-wxversion.select("2.6")
 import wx
 import wx.lib.masked.numctrl
 import wx.lib.stattext
@@ -31,7 +29,9 @@ def create(parent):
     return preferences(parent)
 
 [wxID_PREFERENCES, wxID_PREFERENCESAUDIOBROWSE, wxID_PREFERENCESAUDIOPATH, 
- wxID_PREFERENCESBUTTON1, wxID_PREFERENCESBUTTON2, wxID_PREFERENCESFONTSLIDE, 
+ wxID_PREFERENCESBROWSER, wxID_PREFERENCESBROWSERBUTTON, 
+ wxID_PREFERENCESBROWSERTEXT, wxID_PREFERENCESBUTTON1, 
+ wxID_PREFERENCESBUTTON2, wxID_PREFERENCESFONTSLIDE, 
  wxID_PREFERENCESGENSTATICTEXT1, wxID_PREFERENCESGENSTATICTEXT2, 
  wxID_PREFERENCESGENSTATICTEXT3, wxID_PREFERENCESGENSTATICTEXT4, 
  wxID_PREFERENCESGENSTATICTEXT5, wxID_PREFERENCESGENSTATICTEXT6, 
@@ -42,39 +42,39 @@ def create(parent):
  wxID_PREFERENCESSTREAMRIPBROWSE, wxID_PREFERENCESTERMPATH, 
  wxID_PREFERENCESTEXTCTRL1, wxID_PREFERENCESVIDEOBROWSE, 
  wxID_PREFERENCESVIDEOPATH, wxID_PREFERENCESXTERMBROWSE, 
-] = [wx.NewId() for _init_ctrls in range(26)]
+] = [wx.NewId() for _init_ctrls in range(29)]
 
 class preferences(wx.Dialog):
     def _init_ctrls(self, prnt):
         # generated method, don't edit
         wx.Dialog.__init__(self, id=wxID_PREFERENCES, name='preferences',
-              parent=prnt, pos=wx.Point(289, 197), size=wx.Size(451, 321),
+              parent=prnt, pos=wx.Point(294, 190), size=wx.Size(447, 342),
               style=wx.DEFAULT_DIALOG_STYLE, title='Preferences')
-        self.SetClientSize(wx.Size(451, 321))
+        self.SetClientSize(wx.Size(447, 342))
         self.SetBackgroundColour(wx.Colour(222, 223, 206))
         self.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.SetThemeEnabled(True)
 
         self.genStaticText1 = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESGENSTATICTEXT1,
-              label='Full path to audio player:', name='genStaticText1',
-              parent=self, pos=wx.Point(8, 16), size=wx.Size(137, 13), style=0)
+              label=u'Audio player:', name='genStaticText1', parent=self,
+              pos=wx.Point(8, 16), size=wx.Size(73, 13), style=0)
         self.genStaticText1.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
-        self.genStaticText1.SetBackgroundColour(wx.Colour(222, 223, 206))
+        self.genStaticText1.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText1.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText1.SetThemeEnabled(True)
 
         self.genStaticText2 = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESGENSTATICTEXT2,
-              label=u'Full path to nsv player:', name='genStaticText2',
-              parent=self, pos=wx.Point(8, 48), size=wx.Size(126, 13), style=0)
+              label=u'Nsv (video) player:', name='genStaticText2', parent=self,
+              pos=wx.Point(8, 48), size=wx.Size(104, 13), style=0)
         self.genStaticText2.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
-        self.genStaticText2.SetBackgroundColour(wx.Colour(222, 223, 206))
+        self.genStaticText2.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText2.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText2.SetThemeEnabled(True)
 
         self.button1 = wx.Button(id=wxID_PREFERENCESBUTTON1, label='Save',
-              name='button1', parent=self, pos=wx.Point(290, 280),
+              name='button1', parent=self, pos=wx.Point(290, 304),
               size=wx.Size(80, 24), style=0)
         self.button1.SetDefault()
         self.button1.SetFont(wx.Font(7, 77, wx.NORMAL, wx.NORMAL, False,
@@ -84,7 +84,7 @@ class preferences(wx.Dialog):
               id=wxID_PREFERENCESBUTTON1)
 
         self.button2 = wx.Button(id=wxID_PREFERENCESBUTTON2, label='Cancel',
-              name='button2', parent=self, pos=wx.Point(80, 280),
+              name='button2', parent=self, pos=wx.Point(80, 304),
               size=wx.Size(80, 24), style=0)
         self.button2.SetFont(wx.Font(7, 77, wx.NORMAL, wx.NORMAL, False,
               u'Sans'))
@@ -93,7 +93,7 @@ class preferences(wx.Dialog):
               id=wxID_PREFERENCESBUTTON2)
 
         self.audiopath = wx.TextCtrl(id=wxID_PREFERENCESAUDIOPATH,
-              name='audiopath', parent=self, pos=wx.Point(168, 16),
+              name='audiopath', parent=self, pos=wx.Point(144, 16),
               size=wx.Size(200, 22), style=0, value='/usr/bin/xmms')
         self.audiopath.SetFont(wx.Font(7, 77, wx.NORMAL, wx.NORMAL, False,
               u'Sans'))
@@ -102,7 +102,7 @@ class preferences(wx.Dialog):
         self.audiopath.SetBestFittingSize(wx.Size(200, 22))
 
         self.videopath = wx.TextCtrl(id=wxID_PREFERENCESVIDEOPATH,
-              name='videopath', parent=self, pos=wx.Point(168, 48),
+              name='videopath', parent=self, pos=wx.Point(144, 48),
               size=wx.Size(200, 22), style=0, value='/usr/bin/mplayer')
         self.videopath.SetFont(wx.Font(7, 77, wx.NORMAL, wx.NORMAL, False,
               u'Sans'))
@@ -111,26 +111,25 @@ class preferences(wx.Dialog):
         self.videopath.SetBestFittingSize(wx.Size(200, 22))
 
         self.genStaticText3 = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESGENSTATICTEXT3,
-              label='Full path to x-terminal:', name='genStaticText3',
-              parent=self, pos=wx.Point(8, 80), size=wx.Size(125, 13), style=0)
+              label=u'Xterminal:', name='genStaticText3', parent=self,
+              pos=wx.Point(8, 80), size=wx.Size(58, 13), style=0)
         self.genStaticText3.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
-        self.genStaticText3.SetBackgroundColour(wx.Colour(222, 223, 206))
+        self.genStaticText3.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText3.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText3.SetThemeEnabled(True)
 
         self.genStaticText4 = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESGENSTATICTEXT4,
-              label='Full path to streamripper:', name='genStaticText4',
-              parent=self, pos=wx.Point(8, 112), size=wx.Size(143, 13),
-              style=0)
+              label=u'Streamripper:', name='genStaticText4', parent=self,
+              pos=wx.Point(8, 112), size=wx.Size(80, 13), style=0)
         self.genStaticText4.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
-        self.genStaticText4.SetBackgroundColour(wx.Colour(222, 223, 206))
+        self.genStaticText4.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText4.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText4.SetThemeEnabled(True)
 
         self.termpath = wx.TextCtrl(id=wxID_PREFERENCESTERMPATH,
-              name='termpath', parent=self, pos=wx.Point(168, 80),
+              name='termpath', parent=self, pos=wx.Point(144, 80),
               size=wx.Size(200, 22), style=0,
               value='/usr/bin/x-terminal-emulator')
         self.termpath.SetFont(wx.Font(7, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
@@ -140,7 +139,7 @@ class preferences(wx.Dialog):
         self.termpath.SetBestFittingSize(wx.Size(200, 22))
 
         self.rippath = wx.TextCtrl(id=wxID_PREFERENCESRIPPATH, name='rippath',
-              parent=self, pos=wx.Point(168, 112), size=wx.Size(200, 22),
+              parent=self, pos=wx.Point(144, 112), size=wx.Size(200, 22),
               style=0, value='/usr/bin/streamripper')
         self.rippath.SetFont(wx.Font(7, 77, wx.NORMAL, wx.NORMAL, False,
               u'Sans'))
@@ -149,17 +148,17 @@ class preferences(wx.Dialog):
         self.rippath.SetBestFittingSize(wx.Size(200, 22))
 
         self.genStaticText5 = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESGENSTATICTEXT5,
-              label=u'Full path to rip directory:', name='genStaticText5',
-              parent=self, pos=wx.Point(8, 144), size=wx.Size(136, 13),
+              label=u'Path to rip directory:', name='genStaticText5',
+              parent=self, pos=wx.Point(8, 176), size=wx.Size(114, 13),
               style=0)
         self.genStaticText5.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
-        self.genStaticText5.SetBackgroundColour(wx.Colour(222, 223, 206))
+        self.genStaticText5.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText5.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText5.SetThemeEnabled(True)
 
         self.ripdir = wx.TextCtrl(id=wxID_PREFERENCESRIPDIR, name=u'ripdir',
-              parent=self, pos=wx.Point(168, 144), size=wx.Size(200, 22),
+              parent=self, pos=wx.Point(144, 176), size=wx.Size(200, 22),
               style=0, value=u'~/.tunapie/streamripper')
         self.ripdir.SetBackgroundColour(wx.Colour(255, 253, 239))
         self.ripdir.SetFont(wx.Font(7, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
@@ -169,16 +168,16 @@ class preferences(wx.Dialog):
 
         self.servertext = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESSERVERTEXT,
               label=u'Server:', name=u'servertext', parent=self,
-              pos=wx.Point(80, 245), size=wx.Size(42, 13), style=0)
+              pos=wx.Point(80, 277), size=wx.Size(42, 13), style=0)
         self.servertext.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
-        self.servertext.SetBackgroundColour(wx.Colour(222, 223, 206))
+        self.servertext.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.servertext.SetThemeEnabled(True)
         self.servertext.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
 
         self.icecastbutton = wx.RadioButton(id=wxID_PREFERENCESICECASTBUTTON,
               label=u'Icecast', name=u'icecastbutton', parent=self,
-              pos=wx.Point(160, 245), size=wx.Size(96, 21), style=0)
+              pos=wx.Point(160, 272), size=wx.Size(96, 24), style=0)
         self.icecastbutton.SetValue(True)
         self.icecastbutton.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
@@ -186,7 +185,7 @@ class preferences(wx.Dialog):
 
         self.shoutcastbutton = wx.RadioButton(id=wxID_PREFERENCESSHOUTCASTBUTTON,
               label=u'Shoutcast', name=u'shoutcastbutton', parent=self,
-              pos=wx.Point(272, 245), size=wx.Size(96, 21), style=0)
+              pos=wx.Point(272, 272), size=wx.Size(96, 24), style=0)
         self.shoutcastbutton.SetValue(False)
         self.shoutcastbutton.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
@@ -229,7 +228,7 @@ class preferences(wx.Dialog):
 
         self.ripdirbrowse = wx.Button(id=wxID_PREFERENCESRIPDIRBROWSE,
               label=u'Browse', name=u'ripdirbrowse', parent=self,
-              pos=wx.Point(380, 144), size=wx.Size(53, 22), style=0)
+              pos=wx.Point(380, 176), size=wx.Size(53, 24), style=0)
         self.ripdirbrowse.SetFont(wx.Font(7, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
         self.ripdirbrowse.SetThemeEnabled(True)
@@ -238,13 +237,14 @@ class preferences(wx.Dialog):
 
         self.genStaticText6 = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESGENSTATICTEXT6,
               label=u'Max. streams to display in main list (50-500):',
-              name='genStaticText6', parent=self, pos=wx.Point(40, 176),
+              name='genStaticText6', parent=self, pos=wx.Point(56, 208),
               size=wx.Size(252, 13), style=0)
         self.genStaticText6.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
+        self.genStaticText6.SetThemeEnabled(True)
 
         self.maxdisp = wx.TextCtrl(id=wxID_PREFERENCESMAXDISP, name=u'maxdisp',
-              parent=self, pos=wx.Point(328, 176), size=wx.Size(40, 22),
+              parent=self, pos=wx.Point(336, 208), size=wx.Size(40, 22),
               style=0, value=u'100')
         self.maxdisp.SetThemeEnabled(True)
         self.maxdisp.SetBackgroundColour(wx.Colour(255, 253, 239))
@@ -254,14 +254,14 @@ class preferences(wx.Dialog):
 
         self.genStaticText7 = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESGENSTATICTEXT7,
               label=u'Default font size:', name='genStaticText7', parent=self,
-              pos=wx.Point(56, 208), size=wx.Size(94, 13), style=0)
+              pos=wx.Point(56, 240), size=wx.Size(94, 13), style=0)
         self.genStaticText7.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
         self.genStaticText7.SetThemeEnabled(True)
 
         self.fontslide = wx.Slider(id=wxID_PREFERENCESFONTSLIDE, maxValue=12,
               minValue=5, name=u'fontslide', parent=self, point=wx.Point(176,
-              208), size=wx.Size(140, 20), style=wx.SL_HORIZONTAL, value=8)
+              240), size=wx.Size(140, 20), style=wx.SL_HORIZONTAL, value=8)
         self.fontslide.SetThemeEnabled(True)
         self.fontslide.SetMin(5)
         self.fontslide.SetMax(12)
@@ -271,7 +271,7 @@ class preferences(wx.Dialog):
         self.fontslide.Bind(wx.EVT_SCROLL, self.OnFontslideScroll)
 
         self.textCtrl1 = wx.TextCtrl(id=wxID_PREFERENCESTEXTCTRL1,
-              name='textCtrl1', parent=self, pos=wx.Point(336, 208),
+              name='textCtrl1', parent=self, pos=wx.Point(336, 240),
               size=wx.Size(32, 24), style=0, value=u'8')
         self.textCtrl1.SetBackgroundColour(wx.Colour(255, 253, 239))
         self.textCtrl1.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
@@ -280,6 +280,30 @@ class preferences(wx.Dialog):
         self.textCtrl1.SetThemeEnabled(True)
         self.textCtrl1.Enable(True)
 
+        self.browsertext = wx.lib.stattext.GenStaticText(ID=wxID_PREFERENCESBROWSERTEXT,
+              label=u'Web browser:', name=u'browsertext', parent=self,
+              pos=wx.Point(8, 144), size=wx.Size(77, 13), style=0)
+        self.browsertext.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
+              False, u'Sans'))
+        self.browsertext.SetThemeEnabled(True)
+
+        self.browser = wx.TextCtrl(id=wxID_PREFERENCESBROWSER, name=u'browser',
+              parent=self, pos=wx.Point(144, 144), size=wx.Size(200, 22),
+              style=0, value=u'/usr/bin/firefox')
+        self.browser.SetBackgroundColour(wx.Colour(255, 253, 239))
+        self.browser.SetThemeEnabled(True)
+        self.browser.SetFont(wx.Font(7, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
+              u'Sans'))
+
+        self.browserbutton = wx.Button(id=wxID_PREFERENCESBROWSERBUTTON,
+              label=u'Browse', name=u'browserbutton', parent=self,
+              pos=wx.Point(380, 144), size=wx.Size(53, 22), style=0)
+        self.browserbutton.SetFont(wx.Font(7, wx.SWISS, wx.NORMAL, wx.NORMAL,
+              False, u'Sans'))
+        self.browserbutton.SetThemeEnabled(True)
+        self.browserbutton.Bind(wx.EVT_BUTTON, self.OnBrowserbuttonButton,
+              id=wxID_PREFERENCESBROWSERBUTTON)
+
     def __init__(self, parent):
         self._init_ctrls(parent)
 
@@ -327,15 +351,21 @@ class preferences(wx.Dialog):
               False, u'Sans'))
         self.ripdirbrowse.SetFont(wx.Font(size-1, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
-        self.maxdisp.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
+        self.maxdisp.SetFont(wx.Font(size, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
               u'Sans'))
         self.genStaticText7.SetFont(wx.Font(size, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Sans'))
         self.textCtrl1.SetFont(wx.Font(size, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
               u'Sans'))
+        self.browser.SetFont(wx.Font(size-1, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
+              u'Sans'))
+        self.browserbutton.SetFont(wx.Font(size-1, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
+              u'Sans'))
+        self.browsertext.SetFont(wx.Font(size, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
+              u'Sans'))
             
     
-    def setvars(self,media,video,term,rip,home,rdir,shoutice,maxd,fontsize):
+    def setvars(self,media,video,term,rip,home,rdir,shoutice,maxd,fontsize,browser):
         self.audiopath.SetValue(media)
         self.videopath.SetValue(video)
         self.termpath.SetValue(term)
@@ -345,6 +375,7 @@ class preferences(wx.Dialog):
         self.maxdisp.SetValue(str(int(maxd)))
         self.fontslide.SetValue(int(fontsize))
         self.textCtrl1.SetValue(str(int(fontsize)))
+        self.browser.SetValue(browser)
         self.home=home
 
     def OnButton2Button(self, event):
@@ -362,7 +393,7 @@ class preferences(wx.Dialog):
             self.videopath.GetValue(),self.termpath.GetValue(),\
             self.rippath.GetValue(), self.ripdir.GetValue(),\
             self.shoutcastbutton.GetValue(), self.maxdisp.GetValue(),\
-            self.fontslide.GetValue())
+            self.fontslide.GetValue(), self.browser.GetValue())
         self.Close()
 
     def OnAudiobrowseButton(self, event):
@@ -402,6 +433,15 @@ class preferences(wx.Dialog):
                 self.rippath.SetValue(filename)
         finally:
             dlg.Destroy()
+            
+    def OnBrowserbuttonButton(self, event):
+        dlg = wx.FileDialog(self, "Choose a file", "/usr/bin", "", "*", wx.OPEN)
+        try:
+            if dlg.ShowModal() == wx.ID_OK:
+                filename = dlg.GetPath()
+                self.browser.SetValue(filename)
+        finally:
+            dlg.Destroy()
         
 
     def OnRipdirbrowseButton(self, event):
@@ -412,10 +452,13 @@ class preferences(wx.Dialog):
                 self.ripdir.SetValue(dir)
         finally:
             dlg.Destroy()
+    
+    
 
     def OnFontslideScroll(self, event):
         size=str(self.fontslide.GetValue())
         self.textCtrl1.SetValue(size)
         self.setfontsize(size)
+
         
         
