@@ -18,7 +18,7 @@
 #Written using Boa-Constructor.
 #http://boa-constructor.sourceforge.net/
 #
-#Version 2.0.11 21/01/08
+#Version 2.0.12 07/07/08
 
 import wx
 from wx.lib.anchors import LayoutAnchors
@@ -29,6 +29,7 @@ import TunerPrefs
 import AboutTuner
 import RecordQueue
 import TunerInfoDialog
+import AddStream
 import os
 import socket
 import time
@@ -66,8 +67,8 @@ def create(parent):
 ] = [wx.NewId() for _init_coll_maincontext_Items in range(4)]
 
 [wxID_TUNAPIEFRAMEFAVECONTEXTINFO, wxID_TUNAPIEFRAMEFAVECONTEXTPLAY, 
- wxID_TUNAPIEFRAMEFAVECONTEXTRECORD, wxID_TUNAPIEFRAMEFAVECONTEXTREMOVE, 
-] = [wx.NewId() for _init_coll_favecontext_Items in range(4)]
+ wxID_TUNAPIEFRAMEFAVECONTEXTRECORD, wxID_TUNAPIEFRAMEFAVECONTEXTREMOVE,
+ wxID_TUNAPIEFRAMEFAVECONTEXTADDURL] = [wx.NewId() for _init_coll_favecontext_Items in range(5)]
 
 [wxID_TUNAPIEFRAMEFILEMENUPREFERENCES, wxID_TUNAPIEFRAMEFILEMENUQUIT, 
  wxID_TUNAPIEFRAMEFILEMENURECORDQUEUE, wxID_TUNAPIEFRAMEFILEMENURELOAD, 
@@ -107,6 +108,8 @@ class TunapieFrame(wx.Frame):
               kind=wx.ITEM_NORMAL, text=u'Record')
         parent.Append(help='', id=wxID_TUNAPIEFRAMEFAVECONTEXTREMOVE,
               kind=wx.ITEM_NORMAL, text=u'Remove From Favorites')
+        parent.Append(help='', id=wxID_TUNAPIEFRAMEFAVECONTEXTADDURL,
+              kind=wx.ITEM_NORMAL, text=u'Add User Defined Station')
         self.Bind(wx.EVT_MENU, self.OnFavecontextPlayMenu,
               id=wxID_TUNAPIEFRAMEFAVECONTEXTPLAY)
         self.Bind(wx.EVT_MENU, self.OnFavecontextRemoveMenu,
@@ -115,6 +118,8 @@ class TunapieFrame(wx.Frame):
               id=wxID_TUNAPIEFRAMEFAVECONTEXTRECORD)
         self.Bind(wx.EVT_MENU, self.OnFavecontextInfoMenu,
               id=wxID_TUNAPIEFRAMEFAVECONTEXTINFO)
+        self.Bind(wx.EVT_MENU, self.OnFavecontextURLMenu,
+              id=wxID_TUNAPIEFRAMEFAVECONTEXTADDURL)
 
     def _init_coll_menuBar1_Menus(self, parent):
         # generated method, don't edit
@@ -1080,7 +1085,7 @@ class TunapieFrame(wx.Frame):
                 try: 
                     #self.running,output,outputfd=tuner.playvid(videoplayer,self.favurl[selection])
                     self.running=1
-                    thread.start_new_thread(tuner.playvid,(videoplayer,self.favurl[selection]))
+                    tuner.playvid(videoplayer,self.favurl[selection])
                 except IOError:
                     self.contacterror()
                 #try: 
@@ -1092,7 +1097,7 @@ class TunapieFrame(wx.Frame):
                 self.lastmod=1
                 try:
                     self.running=1
-                    thread.start_new_thread(tuner.playselection,(self.mediaplayer,self.favurl[selection]))
+                    tuner.playselection(self.mediaplayer,self.favurl[selection])
                 except IOError:
                     self.contacterror()
             return
@@ -1113,7 +1118,7 @@ class TunapieFrame(wx.Frame):
         if(self.radioselected):
             try: 
                 self.running=1
-                thread.start_new_thread(tuner.playselection,(self.mediaplayer,self.url[selection]))
+                tuner.playselection(self.mediaplayer,self.url[selection])
             except IOError: #if try to play empty stream!
                 self.contacterror()
         return
@@ -1448,6 +1453,18 @@ class TunapieFrame(wx.Frame):
 
     def OnFavecontextInfoMenu(self, event):
         self.OnTunapieToolBarInfoTool(1)
+    
+    def OnFavecontextURLMenu(self, event):
+        if self.reloading==1:
+            return
+        dlg=AddStream.AddURL(self)
+        dlg.setfontsize(self.newsize)
+        try:
+            if dlg.ShowModal()==1:
+                seq.reset()
+                self.retrievedata()
+        finally:
+            dlg.Destroy()
 
     def OnMaincontextInfoMenu(self, event):
         self.OnTunapieToolBarInfoTool(1)
